@@ -1,6 +1,6 @@
 ;;; biblatex.el --- AUCTeX style for `biblatex.sty' version 2.8a.  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2012-2021  Free Software Foundation, Inc.
+;; Copyright (C) 2012-2022  Free Software Foundation, Inc.
 
 ;; Author: Ralf Angeli <angeli@caeruleus.net>
 ;; Maintainer: auctex-devel@gnu.org
@@ -143,7 +143,7 @@
 (defvar LaTeX-biblatex-language-list
   '("catalan" "croatian" "czech" "danish" "dutch" "american" "british"
     "canadian" "australian" "newzealand" "finnish" "french" "german" "austrian"
-    "ngernam" "naustrian" "greek" "italian" "norwegian" "polish" "brazilian"
+    "ngerman" "naustrian" "greek" "italian" "norwegian" "polish" "brazilian"
     "portuguese" "russian" "spanish" "swedish")
   "List of languages supported by biblatex packages.")
 
@@ -203,8 +203,8 @@ for citation keys."
          (TeX-argument-insert
           (TeX-read-string (TeX-argument-prompt t nil "Global postnote"))
           (equal prenote ""))))
-  (let ((items t) (noinsert nil))
-    (while items
+  (let ((items t) (noinsert nil) (reftex--done nil))
+    (while (and items (not reftex--done))
       ;; Prompt for prenote and postnote of the current keys.
       (and TeX-arg-cite-note-p (not current-prefix-arg)
            (let ((TeX-arg-opening-brace "[")
@@ -221,7 +221,11 @@ for citation keys."
                            (fboundp 'reftex-plug-flag)
                            (reftex-plug-flag 3))
                       ;; Use RefTeX when enabled.
-                      (reftex-citation t)
+                      (prog1
+                          (reftex-citation t)
+                        ;; Don't loop when RefTeX citation is done.
+                        ;; (bug#64921)
+                        (setq reftex--done t))
                     ;; Multiple citation keys in each argument are allowed.
                     (TeX-completing-read-multiple
                      (TeX-argument-prompt optional prompt "Key(s)")
@@ -266,7 +270,6 @@ for citation keys."
                      "biblatex" "backend=bibtexu")))))
 
    (TeX-run-style-hooks
-    "etoolbox"
     "keyval"
     "kvoptions"
     "logreq"
@@ -276,9 +279,8 @@ for citation keys."
     ;;; Global Customization
     ;; Setting Package Options
     '("ExecuteBibliographyOptions"
-      [TeX-arg-eval  mapconcat #'identity
-                     (TeX-completing-read-multiple
-                      "Entry type: " LaTeX-biblatex-entrytype) ","]
+      [TeX-arg-completing-read-multiple LaTeX-biblatex-entrytype
+                                        "Entry type"]
       (TeX-arg-key-val LaTeX-biblatex-executebibliographyoptions-options))
     ;;; Bibliography Commands
     ;; Resources
@@ -329,8 +331,7 @@ for citation keys."
     '("defbibcheck" "Name" t)
     ;; Dynamic Entry Sets
     '("defbibentryset" "Set"
-      (TeX-arg-eval mapconcat #'identity (TeX-completing-read-multiple
-                                         "Keys: " (LaTeX-bibitem-list)) ","))
+      (TeX-arg-completing-read-multiple (LaTeX-bibitem-list) "Keys"))
     ;;; Citation Commands
     '("cite" (TeX-arg-conditional TeX-arg-cite-note-p
                                   (["Prenote"] ["Postnote"]) ()) TeX-arg-cite)
@@ -484,13 +485,13 @@ for citation keys."
     '("Rn" "Integer")
     ;; Localization Commands
     '("DefineBibliographyStrings"
-      (TeX-arg-eval completing-read "Language: " LaTeX-biblatex-language-list) t)
+      (TeX-arg-completing-read LaTeX-biblatex-language-list "Language") t)
     '("DefineBibliographyExtras"
-      (TeX-arg-eval completing-read "Language: " LaTeX-biblatex-language-list) t)
+      (TeX-arg-completing-read LaTeX-biblatex-language-list "Language") t)
     '("UndefineBibliographyExtras"
-      (TeX-arg-eval completing-read "Language: " LaTeX-biblatex-language-list) t)
+      (TeX-arg-completing-read LaTeX-biblatex-language-list "Language") t)
     '("DefineHyphenationExceptions"
-      (TeX-arg-eval completing-read "Language: " LaTeX-biblatex-language-list) t)
+      (TeX-arg-completing-read LaTeX-biblatex-language-list "Language") t)
     "NewBibliographyString")
 
    ;; § 3.8.9 natbib Compatibility Commands
@@ -522,22 +523,22 @@ for citation keys."
               (car cmd)
               '(TeX-arg-conditional TeX-arg-cite-note-p
                                     ([LaTeX-arg-biblatex-natbib-notes])
-                                  nil)
+                                    nil)
               #'TeX-arg-cite))))
          cmds))
 
-     ;; Fontification for compat macros does not go into `font-latex.el':
-     (when (and (featurep 'font-latex)
-                (eq TeX-install-font-lock 'font-latex-setup))
-       (font-latex-add-keywords '(("citet"        "*[[{")
-                                  ("Citet"        "*[[{")
-                                  ("citep"        "*[[{")
-                                  ("Citep"        "*[[{")
-                                  ("citealt"      "*[[{")
-                                  ("Citealt"      "*[[{")
-                                  ("citealp"      "*[[{")
-                                  ("Citealp"      "*[[{"))
-                                'biblatex))))
+       ;; Fontification for compat macros does not go into `font-latex.el':
+       (when (and (featurep 'font-latex)
+                  (eq TeX-install-font-lock 'font-latex-setup))
+         (font-latex-add-keywords '(("citet"        "*[[{")
+                                    ("Citet"        "*[[{")
+                                    ("citep"        "*[[{")
+                                    ("Citep"        "*[[{")
+                                    ("citealt"      "*[[{")
+                                    ("Citealt"      "*[[{")
+                                    ("citealp"      "*[[{")
+                                    ("Citealp"      "*[[{"))
+                                  'biblatex))))
 
    (LaTeX-add-environments
     ;;; Bibliography commands
